@@ -1,4 +1,4 @@
-"""Register all Signals."""
+"Notifications app config"
 
 from django.apps import AppConfig
 
@@ -7,7 +7,4 @@ class NotificationsConfig(AppConfig):
     """App Config."""
 
     name = 'notifications'
-
-    def ready(self):
-        """Import signals."""
-        from . import signals
+    default_auto_field = 'django.db.models.AutoField'
