@@ -1,4 +1,7 @@
 from .console import ConsoleChannel  # noqa
 from .base import BaseNotificationChannel  # noqa
-from .channels_websocket import WebSocketChannel  # noqa
+try:
+    from .channels_websocket import WebSocketChannel  # noqa
+except ImportError:
+    pass
 from .push_notification import PushNotificationChannel  # noqa
